from lazytracker.lazytracker import LazyTracker
from lazytracker.tracked import cached
